"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _draftConvert = require("draft-convert");

var _react = _interopRequireDefault(require("react"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var EDITOR_ENTITY_TYPES = {
  LINK: "LINK",
  IMAGE: "IMAGE"
};
var fromHtmlConfig = {
  htmlToEntity: function htmlToEntity(nodeName, node, createEntity) {
    switch (nodeName) {
      case "a":
        return createEntity(EDITOR_ENTITY_TYPES.LINK, "MUTABLE", {
          url: node.href
        });

      case "img":
        return createEntity(EDITOR_ENTITY_TYPES.IMAGE, "IMMUTABLE", {
          alt: node.alt,
          src: node.src
        });

      default:
        return null;
    }
  },
  htmlToBlock: function htmlToBlock(nodeName) {
    switch (nodeName) {
      case "div":
        return {
          type: "atomic",
          data: {}
        };

      default:
        return null;
    }
  }
};
/**
 * Wrapper of draft-convert convertFromHTML that has a predefined config.
 *
 * @param   {String} html - The html to convert into editor state
 *
 * @returns {Object} The RTE contentState (https://draftjs.org/docs/api-reference-content-state)
 */

var fromHtml = function fromHtml(html) {
  return (0, _draftConvert.convertFromHTML)(fromHtmlConfig)(html || "");
};

var toHtmlConfig = {
  blockToHTML: function blockToHTML(block) {
    switch (block.type) {
      case "code-block":
        return /*#__PURE__*/_react["default"].createElement("pre", null);

      case "atomic":
        return /*#__PURE__*/_react["default"].createElement("div", null);

      case "section":
        return /*#__PURE__*/_react["default"].createElement("section", null);

      case "unstyled":
        return /*#__PURE__*/_react["default"].createElement("p", null);

      default:
        return null;
    }
  },
  entityToHTML: function entityToHTML(entity, originalText) {
    switch (entity.type) {
      case EDITOR_ENTITY_TYPES.LINK:
        return /*#__PURE__*/_react["default"].createElement("a", {
          href: entity.data.url
        }, originalText);

      case EDITOR_ENTITY_TYPES.IMAGE:
        return /*#__PURE__*/_react["default"].createElement("img", {
          alt: entity.data.alt,
          src: entity.data.src
        });

      default:
        return originalText;
    }
  }
};
/**
 * Wrapper of draft-convert convertFromHTML that has a predefined config.
 *
 * @param   {Object} contentState - The RTE contentState (https://draftjs.org/docs/api-reference-content-state)
 *
 * @returns {String} the html contained in the provided content state
 */

var toHtml = function toHtml(contentState) {
  return (0, _draftConvert.convertToHTML)(toHtmlConfig)(contentState);
};

var findEntities = function findEntities(contentBlock, callback, contentState, entityType) {
  contentBlock.findEntityRanges(function (character) {
    var entityKey = character.getEntity();
    return entityKey !== null && (!entityType || contentState.getEntity(entityKey).getType() === entityType);
  }, callback);
}; // find all content blocks within a selection range


var getSelectedBlocks = function getSelectedBlocks(selection, contentState) {
  var startKey = selection.getStartKey();
  var endKey = selection.getEndKey();
  var blocks = contentState.getBlockMap();
  var lastWasEnd = false;
  return blocks.skipUntil(function (block) {
    return block.getKey() === startKey;
  }).takeUntil(function (block) {
    if (lastWasEnd) return true;

    if (block.getKey() === endKey) {
      lastWasEnd = true;
    }

    return false;
  });
};
/**
 * Get the selection ranges for entities of a given type within a selection range
 *
 * @param  {Object} selectionState - The RTE selectionState (https://draftjs.org/docs/api-reference-selection-state)
 * @param  {Object} contentState   - The RTE contentState (https://draftjs.org/docs/api-reference-content-state)
 * @param  {String} entityType     - The entity type to find selection ranges for
 *
 * @return {Object} The selection ranges of desired entities within the total selection range
 */


var getSelectedEntities = function getSelectedEntities(selection, contentState, entityType) {
  if (!selection || !contentState) return null;
  var startKey = selection.getStartKey();
  var endKey = selection.getEndKey();
  var selectedBlocks = getSelectedBlocks(selection, contentState);
  var entityRanges = {};
  var found = false;
  selectedBlocks.forEach(function (block) {
    var key = block.getKey();
    entityRanges[key] = [];
    var start = 0;
    var end = block.getText().length;

    if (key === startKey) {
      start = selection.getStartOffset();
    }

    if (key === endKey) {
      end = selection.getEndOffset();
    }

    findEntities(block, function (entityStart, entityEnd) {
      var startBefore = start < entityStart && end > entityStart;
      var endAfter = end > entityEnd && start < entityEnd;
      var startWithin = start > entityStart && start < entityEnd;
      var endWithin = end > entityStart && end < entityEnd;
      var selectionInside = startWithin || endWithin;
      var exactSelection = start === entityStart && end === entityEnd;

      if (startBefore || endAfter || selectionInside || exactSelection) {
        entityRanges[key].push({
          start: entityStart,
          end: entityEnd
        });
        found = true;
      }
    }, contentState, entityType);
  });
  return {
    entityRanges: entityRanges,
    found: found
  };
};
/**
 * Get the text currently selected in the RichTextEditor
 * see: https://github.com/facebook/draft-js/issues/442#issuecomment-223816158
 *
 * @param  {Object} selectionState - The RTE selectionState (https://draftjs.org/docs/api-reference-selection-state)
 * @param  {Object} contentState   - The RTE contentState (https://draftjs.org/docs/api-reference-content-state)
 * @param  {String} blockDelimiter - Delimiter to join separate selected blocks
 *
 * @return {String} The selected text in the editor as a string
 */


var getSelectedText = function getSelectedText(selection, contentState) {
  var blockDelimiter = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : "\n";
  if (!selection || !contentState) return null;
  var startKey = selection.getStartKey();
  var endKey = selection.getEndKey();
  var selectedBlock = getSelectedBlocks(selection, contentState);
  return selectedBlock.map(function (block) {
    var key = block.getKey();
    var text = block.getText();
    var start = 0;
    var end = text.length;

    if (key === startKey) {
      start = selection.getStartOffset();
    }

    if (key === endKey) {
      end = selection.getEndOffset();
    }

    text = text.slice(start, end);
    return text;
  }).join(blockDelimiter);
};

var _default = {
  EDITOR_ENTITY_TYPES: EDITOR_ENTITY_TYPES,
  findEntities: findEntities,
  fromHtml: fromHtml,
  getSelectedEntities: getSelectedEntities,
  getSelectedText: getSelectedText,
  toHtml: toHtml
};
exports["default"] = _default;